@@ -43,6 +43,7 @@ parseDoc opts bs = do
                         , psReferenceMap = mempty
                         , psAutoReferenceMap = mempty
                         , psNoteMap = mempty
+                        , psLastAttributeLine = 0
                         , psAttributes = mempty
                         , psAttrParserState = Nothing
                         , psIds = mempty
@@ -438,7 +439,6 @@ blockQuoteSpec =
       skipMany spaceOrTab
       asciiChar '>'
       followedByWhitespace
-      skipMany spaceOrTab
       pure True
   , blockContainsBlock = Just Normal
   , blockContainsLines = False
@@ -749,7 +749,9 @@ attrSpec =
       case parseAttributes Nothing bs of
         Done (attr, off)
           | B8.all isWs (B8.drop off bs) -> do
-             updateState $ \st -> st{ psAttributes = psAttributes st <> attr }
+             linenum <- sourceLine
+             updateState $ \st -> st{ psAttributes = psAttributes st <> attr
+                                    , psLastAttributeLine = linenum - 1 }
              pure container
           | otherwise -> do
              ils <- parseTextLines container
@@ -915,6 +917,7 @@ data PState =
   , psReferenceMap :: ReferenceMap
   , psAutoReferenceMap :: ReferenceMap
   , psNoteMap :: NoteMap
+  , psLastAttributeLine :: Int
   , psAttributes :: Attr
   , psAttrParserState :: Maybe AttrParserState
   , psIds :: Set ByteString
@@ -957,7 +960,6 @@ checkContinuations = go . reverse . NonEmpty.toList
                           replicateM_ (length (c:cs)) closeCurrentContainer
 
 
-{-# INLINE processLines #-}
 processLines :: P ()
 processLines = do
   -- check continuations for open containers and close any that don't match
@@ -1038,7 +1040,6 @@ finalizeDocument = do
     _ :| [] -> closeCurrentContainer >> finalize <$> getTip
     _ -> closeCurrentContainer >> finalizeDocument
 
-{-# INLINE closeCurrentContainer #-}
 -- | Close container and add to parent container.
 closeCurrentContainer :: P ()
 closeCurrentContainer = do
@@ -1064,16 +1065,17 @@ closeCurrentContainer = do
                      c{ containerEndLine = psLastLine st
                       , containerEndColumn = psLastColumnPrevLine st } :| [] }
 
-{-# INLINE modifyContainers #-}
 modifyContainers :: (NonEmpty Container -> NonEmpty Container) -> P ()
 modifyContainers f =
   updateState $ \st -> st{ psContainerStack = f (psContainerStack st) }
 
-{-# INLINE addContainer #-}
 addContainer :: BlockSpec -> Int -> ContainerData -> P ()
 addContainer bspec curcol bdata = do
   curline <- sourceLine
-  attr <- psAttributes <$> getState
+  lastAttrLine <- psLastAttributeLine <$> getState
+  attr <- if curline == lastAttrLine + 1
+             then psAttributes <$> getState
+             else pure mempty  -- ignore attributes with intervening blank line
   opts <- psParseOptions <$> getState
   let newcontainer = emptyContainer { containerSpec = bspec
                                     , containerStartLine = curline
@@ -1122,7 +1124,6 @@ gobbleSpaceToIndent indent = do
   when (curindent < indent) $
      optional_ (spaceOrTab *> gobbleSpaceToIndent indent)
 
-{-# INLINE getTip #-}
 -- Get tip of container stack.
 getTip :: P Container
 getTip = NonEmpty.head . psContainerStack <$> getState
@@ -1131,10 +1132,13 @@ closeContainingSections :: Int -> P ()
 closeContainingSections lev = do
   tip <- getTip
   case containerData tip of
-    SectionData lev' _ | lev' >= lev ->
-      closeCurrentContainer >>
-      closeContainingSections lev
-    _ -> pure ()
+    SectionData lev' _
+      | lev' >= lev -> closeCurrentContainer >> closeContainingSections lev
+      | otherwise -> pure ()  -- section with lower level, stop
+    _ | blockContainsBlock (containerSpec tip) /= Just Normal ->
+        -- close containers that can't directly contain sections (e.g., List)
+        closeCurrentContainer >> closeContainingSections lev
+    _ -> pure ()  -- container can hold sections, stop here
 
 -- TODO avoid detour through String
 toIdentifier :: ByteString -> ByteString
